#ifndef __INTEGRALAPI_H__
#define __INTEGRALAPI_H__

#ifdef INTEGRALAPI_EXPORTS
#define INTEGRAL_API __declspec(dllexport) 
#else
#define INTEGRAL_API __declspec(dllimport) 
#endif

	INTEGRAL_API bool LeaveDeviceOpen();  // LeaveDeviceOpen(); is Convenience function. A faster method. USB bus kept open until DeviceClose. 
										   // MUST close USB at program END. 
										   // If not used, each function will open/close the USB automatically.

	INTEGRAL_API bool DeviceClose();	   // only needed if LeaveDeviceOpen() called earlier.

	INTEGRAL_API bool Read_FW_VERSION(char *fw1_str);

	INTEGRAL_API bool GetVideoFormat(char *vid_str_1,   /* Input format*/
											 char *vid_str_2,   /* Output active port*/
											 char *vid_str_3,   /* Color Space*/
											 char *vid_str_4,   /* Source info*/
											 char *vid_str_5);  /* HDR info*/


	INTEGRAL_API bool SetActivePort(INTEGRAL_INPORT Port);
	INTEGRAL_API bool SetAudioSource(INTEGRAL_INAUDIO Audio);
	INTEGRAL_API bool SetAutoSwitch(bool State);
	INTEGRAL_API bool SetSwPriority(bool State);
	INTEGRAL_API bool SetHDCP_Version(INTEGRAL_HDCP Hdcp);
	INTEGRAL_API bool SetOut_420(bool State);			//should be used for 600MHz input modes only
	INTEGRAL_API bool Force2c(bool State);				// applies in automix mode, stereo audio
	INTEGRAL_API bool ForceFullAudio(bool State);		// applies in automix mode, all audio
	INTEGRAL_API bool Force51(bool State);				// applies in automix mode, 5.1 channel audio
	INTEGRAL_API bool SetBt2020(bool State);			// applies in automix mode, add BT2020 support in EDID
	INTEGRAL_API bool SetYUV(bool State);				// applies in automix mode, enable/disable YCbCr support
	INTEGRAL_API bool SetAVR(uint8 State);				// special AVR mode.. test only
	
	INTEGRAL_API bool ChangeCustomEdid(EDIDTABLE EdidIndex);	// choose a custom table in custom EDID mode
	INTEGRAL_API bool SetEDID_Mode(INTEGRAL_EDID Edid);			// choose automix/fixed/custom EDID mode
	INTEGRAL_API bool RdTvEDID(INTEGRAL_SINK sinkport, uint8 *pEdidBuf);		// sink edid read
	INTEGRAL_API bool ReadEDID(uint8 *pEdidBuf);						// integral current active edid read
	INTEGRAL_API bool WriteEDID(uint8  * pEdidBuf);		// writes an edid table to integral Custom slot. applies in custom edid mode only
	INTEGRAL_API bool setEdidAlgo(EDIDMIXALGO algo);			// Selects automix EDID algorithm (normal=0, maxaudio=1, copytop=2, maxall=3)

	INTEGRAL_API bool SetCEC(bool State);				// enable/disable cec. default is on.
	INTEGRAL_API bool WriteCEC(char * cec_str);			// send CEC, not save 
	INTEGRAL_API bool SaveCEC_SP(char * cec_str);		// save CEC, button short down
	INTEGRAL_API bool SaveCEC_LP(char * cec_str);		 // save CEC, button long  down
	INTEGRAL_API bool CecLpRepurp(bool State);			// Repurpose CEC button between HDR send / CEC send. [1 = HDR send], default 0/cec
	INTEGRAL_API bool SetCecLa(uint8 cmbLaIndex);		// CEC logical address selection. Default 0 = video processor, 1 = audio system

	INTEGRAL_API bool WriteIF(char * if_str);			// send Info frame
	INTEGRAL_API bool SendAVI(char * avi_str);			// Send a custom AVI and save the value
	INTEGRAL_API bool ReplaceAVI(bool State);			// Use the custom AVI after mode change / power off and on 

	INTEGRAL_API bool ForceHdr(bool State);				// add HDR packet to the automix EDID
	INTEGRAL_API bool HdrForceActivate(bool State);		// IFX demo mode
	INTEGRAL_API bool HdrSamsung(bool State);			// Samsung / FULL HDR mode
	INTEGRAL_API bool HdrIfRx(char *hdr_str);			// HDR infoframe received from Input. 31 bytes max
	INTEGRAL_API bool SpdIfRx(char *spd_str);			// SPD infoframe received from Input. 31 bytes max

	INTEGRAL_API bool SetLogoLed(bool State);
	INTEGRAL_API bool SetBlueLed(bool State);
	
	INTEGRAL_API bool SetIntegralState(INTEGRAL_CMD cmd, BYTE Value);	// fast mode to change states. check CMD_INTEGRAL enum
	INTEGRAL_API bool ReadIntegralState(uint8 *pIntegralState);			// read current array of integral states
	INTEGRAL_API bool factoryReset(bool Status);
	
	INTEGRAL_API bool set3D(uint8 State);
	INTEGRAL_API bool setAviPers(uint8 State);
	INTEGRAL_API bool setHpdForce(uint8 State);
	INTEGRAL_API bool setEvenOdd(uint8 State);
	INTEGRAL_API bool setSenderReceiver(uint8 State);
	INTEGRAL_API bool setSplitEnable(uint8 State);


#endif /*__INTEGRALAPI_H__*/