// This example project highlights the use of the Integral API library. 
// compile with: /EHsc /link IntegralLibrary.lib
// This project is generated in MS Visual Studio 2015 using v120_xp platform toolset

#include "stdafx.h"
#include "windows.h"
#include "types.h"
#include "defaultedid.h"
#include "integralapi_enum.h"
#include "integralapi.h"

bool GetIntegralStatus(uint8 *RdStatus);

int _tmain(int argc, _TCHAR* argv[])
{
	bool St;
	char vid_str_1[100];
	char vid_str_2[100];
	char vid_str_3[100];
	char vid_str_4[100];
	char vid_str_5[100];
	char fw1_str[20];
	char hdr_str[100];
	char spd_str[100];

	unsigned char IntegralState[100];
	unsigned char RdEdid[256];

	LeaveDeviceOpen(); 	// If use LeaveDeviceOpen(); everything is much faster.  
						// Remember also to use DeviceClose(); before exit the program

	Read_FW_VERSION(fw1_str);
	GetVideoFormat(vid_str_1, vid_str_2, vid_str_3, vid_str_4, vid_str_5);
	printf("%s\n", fw1_str);
	printf("%s\n", vid_str_1);
	printf("%s\n", vid_str_2);
	printf("%s\n", vid_str_3);
	printf("%s\n", vid_str_4);
	printf("%s\n", vid_str_5);

	//*****************************************************
	St = GetIntegralStatus(IntegralState);  //local function below
	if (St == false) {
		printf("\nError reading integral...\n");
		return(false);
	}

	memset(hdr_str, 0, sizeof(hdr_str));
	HdrIfRx(hdr_str);
	printf("HDR IF RECEIVED: %s\n", hdr_str);

	memset(spd_str, 0, sizeof(spd_str));
	SpdIfRx(spd_str);
	printf("SPD IF RECEIVED: %s\n", spd_str);

	//*****************************************************
	printf("\ntesting ChangeCustomEdid e4k30_444_300MHz\n");
	ChangeCustomEdid(e4k50_444_600MHz_HDR_BT2020_AllSound);

	//*****************************************************
	St = WriteIF("87:01:17:5c:02:00:D0:84:80:3E:C2:33:C4:86:4C:1D:B8:0B:13:3D:42:40:A0:0F:05:00");
	if (St == false) {
		printf("Error Writing IF values.\n");
	}
	//*****************************************************
	St = WriteCEC("54:44:02");
	if (St == false) {
		printf("Error Writing CEC values.\n");
	}

	//*****************************************************
	St = SaveCEC_SP("50:04");
	if (St == false) {
		printf("\nError Writing CEC_SP values.\n");
	}
	//*****************************************************
	St = SaveCEC_LP("0F:36");
	if (St == false) {
		printf("Error Writing CEC_LP values.\n");
	}

	//*****************************************************
	printf("Selecting Port B.\n");
	SetActivePort(INPORT_B);
	printf("\nPress ENTER key to Continue\n");  getchar();
	//*****************************************************
	printf("Selecting Port A.\n");
	SetActivePort(INPORT_A);
	printf("\nPress ENTER key to Continue\n");  getchar();
	//*****************************************************
	printf("Selecting AUDIO JACK.\n");
	SetAudioSource(AUDIO_JACK);
	printf("\nPress ENTER key to Continue\n");  getchar();
	//*****************************************************
	printf("Selecting AUDIO HDMI.\n");
	SetAudioSource(AUDIO_HDMI);
	printf("\nPress ENTER key to Continue\n");  getchar();

	// or can use a generic state machine call
    // SetIntegralState(AUDIO_SOURCE, AUDIO_JACK);  //SetIntegralState() is a generic function to modify Integral state variables
	// SetIntegralState(AUDIO_SOURCE, AUDIO_HDMI);

	//*****************************************************
	printf("Reading Sink A  EDID.\n");
	St = RdTvEDID(SINK_A, RdEdid);
	if (St == true) {
		printf("\nReading EDID values.\n");
		for (int i = 0; i < 256; i++) {
			if (!(i % 16))
				printf("\n");
			printf("%02X ", RdEdid[i]);
		}
	}
	else {
		printf("\nError reading edid values.\n");
	}
	printf("\nPress ENTER key to Continue\n");  getchar();

	//*****************************************************
	printf("Reading Sink B  EDID.\n");
	St = RdTvEDID(SINK_B, RdEdid);
	if (St == true) {
		printf("\nReading EDID values.\n");
		for (int i = 0; i < 256; i++) {
			if (!(i % 16))
				printf("\n");
			printf("%02X ", RdEdid[i]);
		}
	}
	else {
		printf("\nError reading edid values.\n");
	}

	printf("\nPress ENTER key to Continue\n"); getchar();

	//*****************************************************
	printf("Reading active EDID.\n");
	St = ReadEDID(RdEdid);
	if (St == true) {
		printf("\nReading EDID values.\n");
		for (int i = 0; i<256; i++) {
			if (!(i % 16))
				printf("\n");
			printf("%02X ", RdEdid[i]);
		}
	}
	else {
		printf("\nError reading edid values.\n");
	}
	printf("\nPress ENTER key to Continue\n"); getchar();

	//*****************************************************
	printf("\nWriting Default EDID.\n");
	St = WriteEDID(FixedEdid);
	if (St == true) {
		printf("\nWriting EDID values...\n");
		for (int i = 0; i<256; i++) {
			if (!(i % 16))
				printf("\n");
			printf("%02X ", FixedEdid[i]);
		}
	}
	else {
		printf("\nError writing edid values.\n");
	}

	printf("\nPress ENTER key to Continue\n"); getchar();
	//*****************************************************
	printf("Reading back the active EDID.\n");
	St = ReadEDID(RdEdid);
	if (St == true) {
		printf("\nReading EDID values.\n");
		for (int i = 0; i<256; i++) {
			if (!(i % 16))
				printf("\n");
			printf("%02X ", RdEdid[i]);
		}
	}
	else {
		printf("\nError reading edid values.\n");
	}
	printf("\nPress ENTER key to Continue\n"); getchar();


	DeviceClose();  // close now USB device
	return 0;
}

bool GetIntegralStatus(uint8 *RdStatus)
{
	bool St;

	St = ReadIntegralState(RdStatus);
	if (St == false) {
		return(St);
	}

	if (St == true) {
		switch (RdStatus[eINPUT]) {   //  [0] INPUT    current active input port
		case INPORT_A:
			printf("\nPort A selected\n");
			break;
		case INPORT_B:
			printf("\nPort B selected\n");
			break;
		}
		switch (RdStatus[eAUDIO]) { //  [1] AUDIO,	 audio replacement selector slide
		case AUDIO_HDMI:
			printf("AUDIO HDMI\n");
			break;
		case AUDIO_AUTO:
			printf("AUDIO AUTO\n");
			break;
		case AUDIO_JACK:
			printf("AUDIO JACK\n");
			break;
		}
		switch (RdStatus[eEDID]) {  //  [2] EDID,	 edid selector slide
		case EDID_AUTOMIX:
			printf("EDID AUTOMIX\n");
			break;
		case EDID_FIXED:
			printf("EDID FIXEDd\n");
			break;
		case EDID_CUSTOM:
			printf("EDID CUSTOM\n");
			break;
		}
		switch (RdStatus[eENC]) { //  [3] ENC,	 HDCP selector slide
		case HDCP_14:
			printf("HDCP 1.4\n");
			break;
		case HDCP_22:
			printf("HDCP 2.2\n");
			break;
		}
		switch (RdStatus[eDOWNS]) {  //  [4] DOWNS	 4:2:0 down sampling selector
		case 0x00:
			printf("4:2:0 down sampling disabled\n");
			break;
		case 0x01:
			printf("4:2:0 down sampling enabled\n");
			break;
		}
		switch (RdStatus[eAUTOSW]) { //  [6] AUTOSW  Auto switching of the inputs
		case 0x00:
			printf("Auto switching disabled\n");
			break;
		case 0x01:
			printf("Auto switching enabled\n");
			break;
		}
		if (RdStatus[eSwAudio] == SLIDESW_MIDDLE) { //  [11] SW6_state  Slide switch AUDIO SELECTION
			printf("AUDIO slide switch: middle\n");
		}
		else {
			printf("AUDIO slide switch: left/right\n");
		}
		if (RdStatus[eSwHdcp] == SLIDESW_MIDDLE) { //  [10] SW5_state  Slide switch hdcp SELECTION
			printf("HDCP  slide switch: middle\n");
		}
		else {
			printf("HDCP  slide switch: left/right\n");
		}
		if (RdStatus[eSwEdid] == SLIDESW_MIDDLE) { //  [9] SW4_state  Slide switch edid SELECTION
			printf("EDID  slide switch: middle\n");
		}
		else {
			printf("EDID  slide switch: left/right\n");
		}

	}
	return(St);
}
